@@ -1,9 +1,9 @@
 import datetime
 from typing import Dict
-from ayaka import AyakaBox, AyakaConfig
+from ayaka import AyakaCat, AyakaConfig
 
-app = AyakaBox("时区助手")
-app.help = """时区助手
+cat = AyakaCat("时区助手")
+cat.help = """时区助手
 - tz_add <name> <timezone> 添加一条时区转换，东八区为8，西八区为-8，例如
     tz_add 北京 8
     tz_add 伦敦 0
@@ -17,20 +17,20 @@ app.help = """时区助手
 
 
 class Config(AyakaConfig):
-    __config_name__ = app.name
+    __config_name__ = cat.name
     data: Dict[str, int] = {}
 
 
 config = Config()
 
 
-@app.on_cmd(cmds="tz_add")
+@cat.on_cmd(cmds="tz_add")
 async def tz_add():
     try:
-        name = str(app.args[0])
-        timezone = int(app.args[1])
+        name = str(cat.args[0])
+        timezone = int(cat.args[1])
     except:
-        await app.send(app.help)
+        await cat.send_help()
         return
 
     timezone = (timezone+8) % 24 - 8
@@ -38,7 +38,7 @@ async def tz_add():
     config.data[name] = timezone
     config.save()
 
-    await app.send("添加成功："+get_info(name, timezone))
+    await cat.send("添加成功："+get_info(name, timezone))
 
 
 def get_info(name, timezone):
@@ -51,23 +51,23 @@ def get_info(name, timezone):
     return f"[{name}] {timezone}"
 
 
-@app.on_cmd(cmds="tz_list")
+@cat.on_cmd(cmds="tz_list")
 async def tz_list():
     data = config.data
     items = []
     for name, timezone in data.items():
         items.append(get_info(name, timezone))
     if items:
-        await app.send("\n".join(items))
+        await cat.send("\n".join(items))
     else:
-        await app.send("目前没有设置任何时区转换")
+        await cat.send("目前没有设置任何时区转换")
 
 
-@app.on_cmd(cmds="tz")
+@cat.on_cmd(cmds="tz")
 async def tz():
-    name = str(app.arg)
+    name = str(cat.arg)
     if not name:
-        await app.send(app.help)
+        await cat.send_help()
         return
 
     data = config.data
@@ -77,12 +77,12 @@ async def tz():
         try:
             timezone = int(name)
         except:
-            await app.send("不存在可用的时区转换")
-            await app.send(app.help)
+            await cat.send("不存在可用的时区转换")
+            await cat.send_help()
             return
 
     td = datetime.timedelta(hours=timezone)
     tz = datetime.timezone(td)
     time = datetime.datetime.now(tz=tz)
     t = time.strftime("%Y-%m-%d %H:%M:%S")
-    await app.send(t)
+    await cat.send(t)
